@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: acpi-linux.c,v 1.10 2004/05/16 12:39:26 kevinv Exp $
+ $Id: acpi-linux.c,v 1.12 2005/01/14 04:06:40 ryanl Exp $
  */
 
 /*
@@ -270,6 +270,7 @@ gboolean acpi_linux_init(struct acpi_info * acpiinfo)
     }
   }
 
+  close(fd);
   acpiinfo->event_fd = -1;
   return FALSE;
 }
@@ -313,8 +314,6 @@ gboolean acpi_process_event(struct acpi_info * acpiinfo)
 {
     gsize i;
     int evt;
-    char * s;
-    /*    char str[1024];*/
     gboolean result = FALSE;
     GString *buffer;
     GError *gerror=NULL;
