@@ -76,8 +76,8 @@ static gunichar currency_code[] = {164, 163, 165, 162, 36, 8364, -1};
 /* sup1 frac12 */
 /* static const gchar *one_list = "¹œŒ"; */
 static gunichar one_code[] = {185, 178, 179, 188, 189, 190, -1};
-/* µ ¶ ® ¿ |  */
-static gunichar misc_code[] = {181, 182, 174, 191, 124, -1};
+/* µ ¶ ® ¿ ¡ |  */
+static gunichar misc_code[] = {181, 182, 174, 191, 161, 124, -1};
 
 static const gunichar *chartable[] = {
 	def_code,
@@ -594,7 +594,7 @@ about (BonoboUIComponent *uic,
 	  /* If your charset supports it, please use U00F1 to replace the "n"
 	   * in "Muniz". */
 	  _("Alexandre Muniz <munizao@xprt.net>"),
-	  _("Kevin Vandersloot"),
+	  "Kevin Vandersloot",
 	  NULL
   };
 
@@ -606,43 +606,19 @@ about (BonoboUIComponent *uic,
 
   const gchar *translator_credits = _("translator_credits");
 
-  if (curr_data->about_dialog) {
-	gtk_window_set_screen (GTK_WINDOW (curr_data->about_dialog),
-			       gtk_widget_get_screen (curr_data->applet));
-
-	gtk_window_present (GTK_WINDOW (curr_data->about_dialog));
-	return;
-  }
-  
-  pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-		  "charpick", 48, 0, NULL);
-   
-  curr_data->about_dialog = gnome_about_new (_("Character Palette"),
-					     VERSION,
-					     _("Copyright (C) 1998"),
-					     _("Gnome Panel applet for selecting strange "
-					     "characters that are not on my keyboard. "
-					     "Released under GNU General Public Licence."),
-					     authors,
-					     documenters,
-					     strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-					     pixbuf);
-  
-  if (pixbuf) 
-  	gdk_pixbuf_unref (pixbuf);
-
-  gtk_window_set_screen (GTK_WINDOW (curr_data->about_dialog),
-			 gtk_widget_get_screen (curr_data->applet));
-  gtk_window_set_wmclass (GTK_WINDOW (curr_data->about_dialog),
-			  "character palette", "Character Palette");
-  gnome_window_icon_set_from_file (GTK_WINDOW (curr_data->about_dialog),
-				   GNOME_ICONDIR"/charpick.png");
-
-  g_signal_connect(GTK_OBJECT(curr_data->about_dialog), "destroy",
-		     GTK_SIGNAL_FUNC(gtk_widget_destroyed),
-		     &curr_data->about_dialog);
-  gtk_widget_show(curr_data->about_dialog);
-  return;
+  gtk_show_about_dialog (NULL,
+	"name",		_("Character Palette"),
+	"version",	VERSION,
+	"copyright",	"\xC2\xA9 1998, 2004-2005 GNOME Applets Maintainers "
+			"and others",
+	"comments",	_("Gnome Panel applet for selecting strange "
+			  "characters that are not on my keyboard. "
+			  "Released under GNU General Public Licence."),
+	"authors",	authors,
+	"documenters",	documenters,
+	"translator-credits",	_("translator-credits"),
+	"logo-icon-name",	"charpick",
+	NULL);
 }
 
 
@@ -856,7 +832,7 @@ charpicker_applet_fill (PanelApplet *applet)
   gtk_widget_show_all (GTK_WIDGET (applet));
   
   panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
-                                     NULL,
+                                     DATADIR,
 			             "GNOME_CharpickerApplet.xml",
                                      NULL,
 			             charpick_applet_menu_verbs,
