@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c,v 1.49 2004/12/21 04:43:37 davyd Exp $ */
+/* $Id: gweather-dialog.c,v 1.52 2005/01/16 17:52:58 dcransto Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -18,6 +18,7 @@
 #include <stdlib.h>
 #include <assert.h>
 
+#include <gconf/gconf-client.h>
 #include <gnome.h>
 
 #include "weather.h"
@@ -26,6 +27,9 @@
 #include "gweather-pref.h"
 #include "gweather-dialog.h"
 
+#define MONOSPACE_FONT_DIR "/desktop/gnome/interface"
+#define MONOSPACE_FONT_KEY MONOSPACE_FONT_DIR "/monospace_font_name"
+
 static void gweather_dialog_save_geometry (GWeatherApplet *gw_applet)
 {
 	GtkWidget *window;
@@ -122,6 +126,34 @@ static void link_cb (GtkButton *button, gpointer data)
     data = NULL;
 }
 
+static gchar* replace_multiple_new_lines (gchar *s) 
+{
+	gchar *prev_s = s;
+	gint count = 0;
+	gint i;
+	
+	if (s == NULL) {
+		return s;
+	}
+
+	for (;*s != '\0';s++) {
+	
+		count = 0;
+		
+		if (*s == '\n') {
+			s++;
+			while (*s == '\n' || *s == ' ') {
+				count++;
+				s++;
+			}
+		}
+		for (i = count; i > 1; i--) {
+			*(s - i) = ' ';
+		}
+	}
+	return prev_s;
+}
+
 void gweather_dialog_create (GWeatherApplet *gw_applet)
 {
   GtkWidget *weather_vbox;
@@ -545,11 +577,27 @@ void gweather_dialog_display_toggle (GWeatherApplet *gw_applet)
         gweather_dialog_close(gw_applet);
 }
 
+PangoFontDescription *get_system_monospace_font (void)
+{
+    PangoFontDescription *desc = NULL;
+    GConfClient *conf;
+    char *name;
+
+    conf = gconf_client_get_default ();
+    name = gconf_client_get_string (conf, MONOSPACE_FONT_KEY, NULL);
+
+    if (name) {
+    	desc = pango_font_description_from_string (name);
+    	g_free (name);
+    }
+    return desc;
+}
+
 void gweather_dialog_update (GWeatherApplet *gw_applet)
 {
-    const gchar *forecast;
+    gchar *forecast;
     GtkTextBuffer *buffer;
-    /*GdkFont* detailed_forecast_font = gdk_fontset_load ( "fixed" );*/
+    PangoFontDescription *font_desc;
 
     /* Check for parallel network update in progress */
     if(gw_applet->gweather_info == NULL)
@@ -581,21 +629,33 @@ void gweather_dialog_update (GWeatherApplet *gw_applet)
 
     /* Update forecast */
     if (gw_applet->gweather_pref.location->zone_valid) {
+	font_desc = get_system_monospace_font ();
+	if (font_desc) {
+            gtk_widget_modify_font (gw_applet->forecast_text, font_desc);
+            pango_font_description_free (font_desc);
+	}
+	
         buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (gw_applet->forecast_text));
-        forecast = weather_info_get_forecast(gw_applet->gweather_info);
+        forecast = g_strdup(weather_info_get_forecast(gw_applet->gweather_info));
         if (forecast) {
+            forecast = g_strstrip(replace_multiple_new_lines(forecast));
             gtk_text_buffer_set_text(buffer, forecast, -1);
+            g_free(forecast);
         } else {
             gtk_text_buffer_set_text(buffer, _("Forecast not currently available for this location."), -1);
         }
     }
 
     /* Update radar map */
-    if (gw_applet->gweather_pref.radar_enabled) {
-        GdkPixmap *radar = weather_info_get_radar(gw_applet->gweather_info);
-        if (radar) {
-            gtk_image_set_from_pixmap (GTK_IMAGE (gw_applet->radar_image), 
-                                       radar, gw_applet->gweather_info->radar_mask);
+    if (gw_applet->gweather_pref.radar_enabled)
+    {
+        GdkPixbufAnimation *radar;
+	
+	radar = weather_info_get_radar (gw_applet->gweather_info);
+        if (radar)
+	{
+            gtk_image_set_from_animation (GTK_IMAGE (gw_applet->radar_image), 
+                                       radar);
         }
     }
 }
