@@ -1,7 +1,7 @@
 #ifndef __WEATHER_H_
 #define __WEATHER_H_
 
-/* $Id: weather.h,v 1.25 2004/06/26 12:18:43 dsmit Exp $ */
+/* $Id: weather.h,v 1.31 2005/01/24 12:59:05 davyd Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -34,11 +34,16 @@ struct _WeatherLocation {
     gchar *zone;
     gchar *radar;
     gboolean zone_valid;
+    gchar *coordinates;
+    gdouble  latitude;
+    gdouble  longitude;
+    gboolean latlon_valid;
 };
 
 
 
-extern WeatherLocation *weather_location_new (const gchar *untrans_name, const gchar *trans_name, const gchar *code, const gchar *zone, const gchar *radar);
+extern WeatherLocation *weather_location_new (const gchar *untrans_name, const gchar *trans_name, const gchar *code,
+					      const gchar *zone, const gchar *radar, const gchar *coordinates);
 extern WeatherLocation *weather_location_clone (const WeatherLocation *location);
 extern void weather_location_free (WeatherLocation *location);
 extern gboolean weather_location_equal (const WeatherLocation *location1, const WeatherLocation *location2);
@@ -64,6 +69,7 @@ typedef enum _WeatherWindDirection WeatherWindDirection;
 extern const gchar *weather_wind_direction_string (WeatherWindDirection wind);
 
 enum _WeatherSky {
+    SKY_INVALID = -1,
     SKY_CLEAR,
     SKY_BROKEN,
     SKY_SCATTERED,
@@ -163,6 +169,7 @@ typedef time_t WeatherUpdate;
 
 struct _WeatherInfo {
     gboolean valid;
+    gboolean sunValid;
     WeatherLocation *location;
     WeatherUpdate update;
     WeatherSky sky;
@@ -173,6 +180,8 @@ struct _WeatherInfo {
     WeatherWindSpeed windspeed;
     WeatherPressure pressure;
     WeatherVisibility visibility;
+    WeatherUpdate sunrise;
+    WeatherUpdate sunset;
     gchar *forecast;
     gchar *metar_buffer;
     gchar *iwin_buffer;
@@ -181,8 +190,7 @@ struct _WeatherInfo {
     gchar *radar_buffer;
     gchar *radar_url;
     GdkPixbufLoader *radar_loader;
-    GdkPixmap *radar;
-    GdkBitmap *radar_mask;
+    GdkPixbufAnimation *radar;
     GnomeVFSAsyncHandle *metar_handle;
     GnomeVFSAsyncHandle *iwin_handle;
     GnomeVFSAsyncHandle *wx_handle;
@@ -219,20 +227,61 @@ extern const gchar *weather_info_get_wind (WeatherInfo *info);
 extern const gchar *weather_info_get_pressure (WeatherInfo *info);
 extern const gchar *weather_info_get_visibility (WeatherInfo *info);
 extern const gchar *weather_info_get_apparent (WeatherInfo *info);
+extern const gchar *weather_info_get_sunrise(WeatherInfo *info);
+extern const gchar *weather_info_get_sunset(WeatherInfo *info);
 extern const gchar *weather_info_get_forecast (WeatherInfo *info);
-extern GdkPixmap *weather_info_get_radar (WeatherInfo *info);
+extern GdkPixbufAnimation *weather_info_get_radar (WeatherInfo *info);
 
 extern const gchar *weather_info_get_temp_summary (WeatherInfo *info);
 extern gchar *weather_info_get_weather_summary (WeatherInfo *info);
 
 extern void update_finish (WeatherInfo *info);
 
-extern time_t make_time (gint date, gint hour, gint min);
 
 extern void _weather_info_get_pixbuf (WeatherInfo *info, gboolean mini, GdkPixbuf **pixbuf);
 #define weather_info_get_pixbuf_mini(info,pixbuf) _weather_info_get_pixbuf((info), TRUE, (pixbuf))
 #define weather_info_get_pixbuf(info,pixbuf) _weather_info_get_pixbuf((info), FALSE, (pixbuf))
 
+/* Values common to the parsing source files */
+
+#define DATA_SIZE 5000
+
+#define CONST_DIGITS "0123456789"
+#define CONST_ALPHABET "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+
+/* Units conversions and names */
+
+#define TEMP_F_TO_C(f)  (((f) - 32.0) * 0.555556)
+#define TEMP_F_TO_K(f)  (TEMP_F_TO_C(f) + 273.15)
+#define TEMP_C_TO_F(c)  (((c) * 1.8) + 32.0)
+
+#define WINDSPEED_KNOTS_TO_KPH(knots)  ((knots) * 1.851965)
+#define WINDSPEED_KNOTS_TO_MPH(knots)  ((knots) * 1.150779)
+#define WINDSPEED_KNOTS_TO_MS(knots)   ((knots) * 0.514444)
+
+#define PRESSURE_INCH_TO_KPA(inch)   ((inch) * 3.386)
+#define PRESSURE_INCH_TO_HPA(inch)   ((inch) * 33.86)
+#define PRESSURE_INCH_TO_MM(inch)    ((inch) * 25.40005)
+#define PRESSURE_INCH_TO_MB(inch)    (PRESSURE_INCH_TO_HPA(inch))
+#define PRESSURE_MBAR_TO_INCH(mbar) ((mbar) * 0.029533373)
+
+#define VISIBILITY_SM_TO_KM(sm)  ((sm) * 1.609344)
+#define VISIBILITY_SM_TO_M(sm)   (VISIBILITY_SM_TO_KM(sm) * 1000)
+
+#define DEGREES_TO_RADIANS(deg)   ((fmod(deg,360.) / 180.) * M_PI)
+#define RADIANS_TO_DEGREES(rad)   ((rad) * 180. / M_PI)
+#define RADIANS_TO_HOURS(rad)     ((rad) * 12. / M_PI)
+
+extern void metar_start_open (WeatherInfo *info);
+extern void iwin_start_open (WeatherInfo *info);
+extern void metoffice_start_open (WeatherInfo *info);
+extern void bom_start_open (WeatherInfo *info);
+extern void wx_start_open (WeatherInfo *info);
+
+extern gboolean requests_init (WeatherInfoFunc cb, WeatherInfo *info);
+extern void request_done (GnomeVFSAsyncHandle *handle, WeatherInfo *info);
+extern void requests_done_check (WeatherInfo *info);
+
 G_END_DECLS
 
 #endif /* __WEATHER_H_ */
