@@ -1249,10 +1249,24 @@ GSwitchItConfigLoadGroupDescriptionsUtf8 (GSwitchItConfig * config)
 					     (lDescr, vDescr), -1, NULL,
 					     NULL, NULL);
 					rv = g_slist_append (rv, nameUtf);
+				} else {
+					rv = g_slist_append (rv, g_strdup(""));
 				}
 			}
 		}
 		XklConfigRecDestroy (&xklConfig);
+		/* Worst case - multiple layous - but SOME of them are multigrouped :((( 
+		   We cannot do much - just add empty descriptions. 
+		   The UI is going to be messy. 
+		   Canadian layouts are famous for this sh.t. */
+		if (g_slist_length (rv) != XklGetNumGroups())
+		{
+			XklDebug (0, "The mismatch between "
+				  "the number of groups: %d and number of layouts: %d\n",
+				  XklGetNumGroups(), g_slist_length (rv));
+			for (i = XklGetNumGroups() - g_slist_length (rv); --i>=0;)
+				rv = g_slist_append (rv, g_strdup(""));
+		}
 	}
 	if (rv == NULL)
 		for (i = XklGetNumGroups (); --i >= 0;)
