@@ -37,12 +37,12 @@ about_cb (BonoboUIComponent *uic,
 	  MultiloadApplet   *ma,
 	  const char        *name)
 {
-    GdkPixbuf        *pixbuf;
-   
     static const gchar *authors[] =
     {
 		"Martin Baulig <martin@home-of-linux.org>",
-		"Todd Kulesza <fflewddur@dropline.net>\n",
+		"Todd Kulesza <fflewddur@dropline.net>",
+		"Benoît Dejean <TazForEver@dlfp.org>",
+		"Davyd Madeley <davyd@madeley.id.au>",
 		NULL
     };
 
@@ -53,39 +53,19 @@ about_cb (BonoboUIComponent *uic,
 		NULL
     };
 
-    const gchar *translator_credits = _("translator_credits");
-
-    if (ma->about_dialog) {
-	gtk_window_set_screen (GTK_WINDOW (ma->about_dialog),
-			       gtk_widget_get_screen (GTK_WIDGET (ma->applet)));
-
-	gtk_window_present (GTK_WINDOW (ma->about_dialog));
-	return;
-    }
-	
-    pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-		    "gnome-monitor", 48, 0, NULL);
-	
-    ma->about_dialog = gnome_about_new (_("System Monitor"), VERSION,
-					"(C) 1999 - 2002 The Free Software Foundation",
-					_("Released under the GNU General Public License.\n\n"
-					  "A system load monitor capable of displaying graphs for CPU, ram, and swap space use, plus network traffic."),
-					authors,
-					documenters,
-					strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-					pixbuf);
-
-    if (pixbuf) 
-	g_object_unref (pixbuf);
-  
-    gtk_window_set_screen (GTK_WINDOW (ma->about_dialog),
-			   gtk_widget_get_screen (GTK_WIDGET (ma->applet)));
-    gtk_window_set_wmclass (GTK_WINDOW (ma->about_dialog), "system monitor",
-			    "System Monitor");
-    g_signal_connect (G_OBJECT (ma->about_dialog), "destroy",
-		      G_CALLBACK (gtk_widget_destroyed), &ma->about_dialog);
-
-    gtk_widget_show (ma->about_dialog);
+    gtk_show_about_dialog (NULL,
+	"name",		_("System Monitor"),
+	"version",	VERSION,
+	"copyright",	"\xC2\xA9 1999-2005 Free Software Foundation "
+			"and others",
+	"comments",	_("A system load monitor capable of displaying graphs "
+			"for CPU, ram, and swap space use, plus network "
+			"traffic."),
+	"authors",	authors,
+	"documenters",	documenters,
+	"translator-credits",	_("translator-credits"),
+	"logo-icon-name",	"gnome-monitor",
+	NULL);
 }
 
 static void
@@ -156,7 +136,7 @@ start_procman_cb (BonoboUIComponent *uic,
 	start_procman (ma);
 }
 
-void
+static void
 multiload_change_size_cb(PanelApplet *applet, gint size, gpointer data)
 {
 	MultiloadApplet *ma = (MultiloadApplet *)data;
@@ -166,7 +146,7 @@ multiload_change_size_cb(PanelApplet *applet, gint size, gpointer data)
 	return;
 }
 
-void
+static void
 multiload_change_orient_cb(PanelApplet *applet, gint arg1, gpointer data)
 {
 	MultiloadApplet *ma = data;
@@ -175,7 +155,7 @@ multiload_change_orient_cb(PanelApplet *applet, gint arg1, gpointer data)
 	return;
 }
 
-void
+static void
 multiload_change_background_cb (PanelApplet *a,
 				PanelAppletBackgroundType type,
 				GdkColor *color,
@@ -215,7 +195,7 @@ multiload_change_background_cb (PanelApplet *a,
 	}
 }
 
-void
+static void
 multiload_destroy_cb(GtkWidget *widget, gpointer data)
 {
 	gint i;
@@ -248,7 +228,7 @@ multiload_destroy_cb(GtkWidget *widget, gpointer data)
 	return;
 }
 
-gboolean
+static gboolean
 multiload_enter_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 {
 	MultiloadApplet *ma;
@@ -266,7 +246,8 @@ multiload_enter_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 	return TRUE;
 }
 
-gboolean
+#if 0
+static gboolean
 multiload_leave_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 {
 	MultiloadApplet *ma;
@@ -280,6 +261,7 @@ multiload_leave_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 		
 	return TRUE;
 }
+#endif /* 0 */
 
 static gboolean
 multiload_button_press_event_cb (GtkWidget *widget, GdkEventButton *event, MultiloadApplet *ma)
@@ -287,7 +269,7 @@ multiload_button_press_event_cb (GtkWidget *widget, GdkEventButton *event, Multi
 	g_return_val_if_fail (event != NULL, FALSE);
 	g_return_val_if_fail (ma != NULL, FALSE);
 
-	if (event->button == 1 && event->type == GDK_2BUTTON_PRESS) {
+	if (event->button == 1 && event->type == GDK_BUTTON_PRESS) {
 		start_procman (ma);
 		return TRUE;
 	}
@@ -343,6 +325,8 @@ multiload_applet_tooltip_update(LoadGraph *g)
 		name = g_strdup(_("Swap Space"));
 	else if (!strncmp(g->name, "loadavg", strlen("loadavg")))
 		name = g_strdup(_("Load Average"));
+	else if (!strncmp (g->name, "diskload", strlen("diskload")))
+		name = g_strdup(_("Disk"));
 	else
 		name = g_strdup(_("Resource"));
 	
@@ -417,6 +401,7 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	ma->graphs[2] = netload_applet_new(ma->applet, NULL);
 	ma->graphs[3] = swapload_applet_new(ma->applet, NULL);
 	ma->graphs[4] = loadavg_applet_new(ma->applet, NULL);
+	ma->graphs[5] = diskload_applet_new(ma->applet, NULL);
 	
 	/* only start and display the graphs the user has turned on */
 
@@ -444,7 +429,7 @@ static const BonoboUIVerb multiload_menu_verbs [] = {
 };		
 
 /* create a box and stuff the load graphs inside of it */
-gboolean
+static gboolean
 multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 {
 	MultiloadApplet *ma;
@@ -464,7 +449,7 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 
 	panel_applet_setup_menu_from_file (applet,
-					   NULL,
+					   DATADIR,
 					   "GNOME_MultiloadApplet.xml",
 					   NULL,
 					   multiload_menu_verbs,
